@@ -7,8 +7,8 @@ print.sig.glm <- function(x, ...){
         "LR"=x$LR[, pVal],
         "score"=x$score[, pVal])
     rownames(m1) <- x$Wald[, coef]
-    m1[, 1:3] <- format.pval(m1[, 1:3])
-    stats::printCoefmat(m1, has.Pvalue = T,
+    m1[, 1:3] <- as.numeric(format.pval(m1[, 1:3]))
+    stats::printCoefmat(m1, has.Pvalue=TRUE,
                         cs.ind=1L,
                         dig.tst=getOption("digits"))
 }
